# Changelog

<!--next-version-placeholder-->

## v1.2.1 (2022-09-30)
### Fix
* Libmagic import error ([`a00fb7b`](https://github.com/Stephen-RA-King/pynball/commit/a00fb7b9656eea1737bd0bab280eded7c11c541c))

## v1.2.0 (2022-09-29)
### Feature
* Add mvproject feature ([`165ecdd`](https://github.com/Stephen-RA-King/pynball/commit/165ecdd77d329d430ee143780709e7467e99ef35))
* Add -n option for mkproject ([`dd57c50`](https://github.com/Stephen-RA-King/pynball/commit/dd57c50cd70555a1b4e1eba0f9e1c69b30ed6bff))

## v1.1.5 (2022-07-22)


## v1.1.4 (2022-07-17)
### Fix
* Make rmproject warning more descriptive ([`e0b14c2`](https://github.com/Stephen-RA-King/pynball/commit/e0b14c2f870c83d41cc190b1548d4e8c2c10f8c3))

## v1.1.3 (2022-07-17)
### Fix
* Change test order for mvproject function ([`e87dabc`](https://github.com/Stephen-RA-King/pynball/commit/e87dabc89d949b1be9a6eb74616ec24390e4c54c))

## v1.1.2 (2022-07-17)
### Fix
* Add exception handling for mvproject ([`3265299`](https://github.com/Stephen-RA-King/pynball/commit/3265299ee5da6f3781d8fa3c070d38bd28bcc384))

## v1.1.1 (2022-07-17)
### Fix
* Error in entrypoint ([`2e95fb1`](https://github.com/Stephen-RA-King/pynball/commit/2e95fb141cda3645135462b160d3696f1be3d5aa))

## v1.1.0 (2022-07-17)
### Feature
* Add venv renaming function ([`df2e727`](https://github.com/Stephen-RA-King/pynball/commit/df2e7275296885b991ae247a9c3fd6ee2e67de44))

### Fix
* Tests.yml - run tests on windows only ([`43adc6e`](https://github.com/Stephen-RA-King/pynball/commit/43adc6ed5c4c6d9a9aaf152086e9ed5d02af25c1))
* Add badges ([`8fc7318`](https://github.com/Stephen-RA-King/pynball/commit/8fc73182ad161b3ff1865a5e1ea663ab9a38645e))
* Add sphinx requirements file ([`55ad58a`](https://github.com/Stephen-RA-King/pynball/commit/55ad58af6a62cbf937ac3c73e62c7a23be62023d))

## v1.0.3 (2022-05-31)
### Fix
* Update uri link ([`764ad41`](https://github.com/Stephen-RA-King/pynball/commit/764ad4117abbf5c3dc10d9f6cdc4eb37e8d9f59d))

## 1.0.2 (2022-05-31)

### First Release of 'pynball'



<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pynball)
